package drawingDemo;

import static java.lang.Math.sin;

public class WaveBase implements ITrigWave {
    
    // private attributes
    protected int wavePeriod = 360;       // wave period in degrees
    protected int numberOfPeriods = 5;    // number of periods inside the wavePeriod
    protected int degrees = 0;            // starting degree for the wave
    protected int amplitude = 50;         // vertical scale factor for the wave
    protected int waveLength = 1;         // wave length in pixels*wavePeriod
    protected int verticalOffset = 100;   // vertical wave offset from the top of the screen in pixels
    protected int horizontalOffset = 100; // horizontal wave offset from the left of the screen in pixels
    protected int degreeIncrement = 1;    // segment increment in degrees
    
    // The following variables represent 2D screen coordinates
    // measured in pixels:
    protected int x = getNewX();
    protected int y = getNewY();
    protected int oldx = getOldX();
    protected int oldy = getOldY();
    
    // constructors
    public WaveBase()
    {
        calculateNextSegment( 1 );
        getOldX();
        getOldY();
    }
    
    // operations

    public int getDegrees() {
        return degrees;
    }

    public void setDegrees(int degrees) {
        this.degrees = degrees;
    }

    @Override // ITrigWave
    public void calculateNextSegment( int degreeIncrement )
    {
        // advance to the next segment
        this.degreeIncrement = degreeIncrement;
        degrees += degreeIncrement;
        degrees = (degrees % wavePeriod == 0) ? 0 : degrees;
        if ( degrees > wavePeriod ) {
            degrees = degrees % wavePeriod;
        }
    }
    
    @Override // ITrigWave
    public int getOldX()
    {
        int temp = oldx;
        oldx = x;
        return temp*waveLength + horizontalOffset;
    }
    
    @Override // ITrigWave
    public int getOldY()
    {
        int temp = oldy;
        oldy = y;
        return temp;
    }
    
    @Override // ITrigWave
    public int getNewX()
    {
        x += degreeIncrement;
        if ( x >= wavePeriod ) {
            x = 0;
            return -1;
        }
        return x*waveLength + horizontalOffset;
    }
    
    @Override // ITrigWave
    public int getNewY()
    {
        return verticalOffset;
        //return y = (int)( -sin( Math.toRadians(x*numberOfPeriods + degrees) ) * amplitude ) + verticalOffset;
    }
}//WaveBase
